summaryrefslogtreecommitdiffstats
path: root/quanta/src/viewmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/viewmanager.cpp')
-rw-r--r--quanta/src/viewmanager.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/quanta/src/viewmanager.cpp b/quanta/src/viewmanager.cpp
index 23fbb063..9446daf6 100644
--- a/quanta/src/viewmanager.cpp
+++ b/quanta/src/viewmanager.cpp
@@ -107,8 +107,8 @@ QuantaView* ViewManager::createView(const TQString &caption)
void ViewManager::createNewDocument()
{
int i = 1;
- while (isOpened(KURL("file:"+i18n("Untitled%1").tqarg(i)))) i++;
- TQString fname = i18n("Untitled%1").tqarg(i);
+ while (isOpened(KURL("file:"+i18n("Untitled%1").arg(i)))) i++;
+ TQString fname = i18n("Untitled%1").arg(i);
QuantaView *view = createView(fname);
#ifdef ENABLE_EDITORS
@@ -257,16 +257,16 @@ void ViewManager::slotCloseOtherTabs()
if (dynamic_cast<QuantaView*>(currentView) && !static_cast<QuantaView*>(currentView)->document())
ToolbarTabWidget::ref()->reparent(0, 0, TQPoint(), false);
KMdiIterator<KMdiChildView*> *it = quantaApp->createIterator();
- //save the tqchildren first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView *> tqchildren;
+ //save the children first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView *> children;
for (it->first(); !it->isDone(); it->next())
{
- tqchildren.append(it->currentItem());
+ children.append(it->currentItem());
}
delete it;
KURL::List modifiedList;
TQValueListIterator<KMdiChildView *> childIt;
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = *childIt;
qView = dynamic_cast<QuantaView*>(view);
@@ -286,7 +286,7 @@ void ViewManager::slotCloseOtherTabs()
if (dlg.exec() == TQDialog::Accepted)
{
filesToSave = dlg.filesToSave();
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = *childIt;
qView = dynamic_cast<QuantaView*>(view);
@@ -311,7 +311,7 @@ void ViewManager::slotCloseOtherTabs()
}
}
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = *childIt;
if (view != currentView)
@@ -427,16 +427,16 @@ bool ViewManager::closeAll(bool createNew)
parser->setSAParserEnabled(false);
KMdiIterator<KMdiChildView*> *it = quantaApp->createIterator();
QuantaView *view;
- //save the tqchildren first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView *> tqchildren;
+ //save the children first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView *> children;
for (it->first(); !it->isDone(); it->next())
{
- tqchildren.append(it->currentItem());
+ children.append(it->currentItem());
}
delete it;
KURL::List modifiedList;
TQValueListIterator<KMdiChildView *> childIt;
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = dynamic_cast<QuantaView*>(*childIt);
if (view)
@@ -455,7 +455,7 @@ bool ViewManager::closeAll(bool createNew)
if (dlg.exec() == TQDialog::Accepted)
{
filesToSave = dlg.filesToSave();
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = dynamic_cast<QuantaView*>(*childIt);
if (view)
@@ -484,7 +484,7 @@ bool ViewManager::closeAll(bool createNew)
disconnect(quantaApp, TQT_SIGNAL(lastChildViewClosed()), this, TQT_SLOT(slotLastViewClosed()));
ToolbarTabWidget::ref()->reparent(0L, 0, TQPoint(), false);
- for (childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt)
+ for (childIt = children.begin(); childIt != children.end(); ++childIt)
{
view = dynamic_cast<QuantaView*>(*childIt);
if (view)